//
//  ChannelTagsDataSource.swift
//  SampleApp
//
//  Created by Federico Zanetello on 4/19/19.
//  Copyright © 2019 David Zhang. All rights reserved.
//

import AmitySDK

final class ChannelTagsDataSource {
    private unowned var client: AmityClient
    private let channelId: String

    weak var dataSourceObserver: DataSourceListener?

    private var channelObject: AmityObject<AmityChannel>?
    private var channelToken: AmityNotificationToken?

    init(client: AmityClient, channelId: String) {
        self.client = client
        self.channelId = channelId

        setupObserver()
    }

    private func setupObserver() {
        let channelRepository: AmityChannelRepository = AmityChannelRepository(client: client)
        channelObject = channelRepository.getChannel(channelId)

        channelToken = channelObject?.observe { [weak self] _, _ in
            self?.dataSourceObserver?.didUpdateDataSource()
        }
    }

    func numberOfTags() -> Int {
        return channelObject?.snapshot?.tags.count ?? 0
    }

    func tag(for indexPath: IndexPath) -> String? {
        guard
            numberOfTags() > indexPath.row,
            let channel: AmityChannel = channelObject?.snapshot else { return nil }

        let channelTags = channel.tags
        return channelTags[indexPath.row]
    }
}
