//
//  GetGlobalFeedStoryTargetsView.swift
//  SampleApp
//
//  Created by Manuchet Rungraksa on 26/1/2567 BE.
//  Copyright © 2567 BE David Zhang. All rights reserved.
//

import Foundation
import AmitySDK
import SwiftUI

struct GetGlobalFeedStoryTargetsView: View {
    
    @ObservedObject var viewModel: StoryTargetListViewModel
    @State var option: AmityGlobalStoryTargetsQueryOption = .all
    @Environment(\.navigationController) var navigationController

    @State private var selection: String?
    @State var storyView: StoryListView?

    var body: some View {
        VStack(alignment: .center) {
            Picker("Sort Type", selection: $option) {
                Text("All").tag(AmityGlobalStoryTargetsQueryOption.all)
                Text("Seen").tag(AmityGlobalStoryTargetsQueryOption.seen)
                Text("Unseen").tag(AmityGlobalStoryTargetsQueryOption.unseen)
                Text("Smart").tag(AmityGlobalStoryTargetsQueryOption.smart)
            }
            .pickerStyle(.segmented)
            
            Button(action: {
                viewModel.queryGlobalFeedStoryTargets(option: option)
            }){
                Text("Query story list")
                    .frame(alignment: .center)
            }.buttonStyle(BorderlessButtonStyle())
            
            if let errorString = viewModel.errorString {
                Text(errorString)
            }
            List(viewModel.storyTargets) { target in
                VStack(alignment: .leading) {
                    Text("Target Id: \(target.targetId)")
                    Text("Target type: \(target.targetType)")
                    Text("Has Unseen: \(target.hasUnseen)" as String)
                    Text("Failed stories count: \(target.failedStoriesCount)" as String)
                        .foregroundColor(target.failedStoriesCount == 0 ? .black : .red)
                    Text("Syncing stories count: \(target.syncingStoriesCount)" as String)
                        .foregroundColor(target.syncingStoriesCount == 0 ? .black : .yellow)
                    Text("Community object id: \(target.community?.communityId == nil ? "nil" : target.community!.communityId)")
                }.onAppear {
                    if self.viewModel.storyTargets.last?.targetId == target.targetId {
                        self.viewModel.fetchNextPage()
                    }
                }.onTapGesture {
                    storyView = StoryListView(viewModel: StoryListViewModel(targetId: target.targetId))

                    self.selection = "storyListView"
                }
            }
            
        }
        
        NavigationLink(
            destination: storyView?.environment(\.navigationController, navigationController),
            tag: "storyListView",
            selection: self.$selection,
            label: {
                EmptyView()
            })
        .buttonStyle(PlainButtonStyle())
        .hidden()
    }
}
