//
//  UserLevelPushNotificationManager.swift
//  SampleApp
//
//  Created by Nontapat Siengsanor on 12/3/2564 BE.
//  Copyright © 2564 BE David Zhang. All rights reserved.
//

import AmitySDK
import Foundation

protocol UserLevelPushNotificationManagerDelegate: AnyObject {
    func manager(_ manager: UserLevelPushNotificationManager, didReceiveNotification notification: AmityUserNotificationSettings)
    func manager(_ manager: UserLevelPushNotificationManager, didFailWithError error: Error)
}

final class UserLevelPushNotificationManager {

    unowned let client: AmityClient
    weak var delegate: UserLevelPushNotificationManagerDelegate?

    var isEnabled: Bool = false
    var modules: [UserNotificationModuleViewModel] = []

    init(client: AmityClient) {
        self.client = client
    }

    func fetchUserNotification() {
        let notificationManager = client.notificationManager
        Task { @MainActor in
            do {
                let notification = try await notificationManager.getSettings()
                self.isEnabled = notification.isEnabled
                self.modules = notification.modules.map { UserNotificationModuleViewModel(type: $0.moduleType, isEnabled: $0.isEnabled, acceptOnlyModerator: $0.roleFilter?.roleIds?.contains("moderator") ?? false ) }
                self.delegate?.manager(self, didReceiveNotification: notification)
            } catch {}
        }
    }

    func updateNotification() {
        let notificationManager = client.notificationManager
        if isEnabled {
            let _modules = modules.map { module -> AmityUserNotificationModule in
                let roleIds: [String] = module.acceptOnlyModerator ? ["moderator"] : []
                return AmityUserNotificationModule(moduleType: module.type, isEnabled: module.isEnabled, roleFilter: .onlyFilter(withRoleIds: roleIds))
            }
            Task { @MainActor in
                do {
                    let _ = try await notificationManager.enable(for: _modules)
                } catch {
                    self.handleResponse(error: error)
                }
            }
        } else {
            Task { @MainActor in
                do {
                    let _ = try await notificationManager.disableAllNotifications()
                } catch {
                    self.handleResponse(error: error)
                }
            }
        }
    }

    private func handleResponse(error: Error?) {
        if let error = error {
            delegate?.manager(self, didFailWithError: error)
        }
        // bring this back when the getSetting issue is fix for a smooth flow
        // fetchUserNotification()
    }
}
