//
//  MetadataInputView.swift
//  SampleApp
//
//  Created by Nishan on 7/12/2566 BE.
//  Copyright © 2566 BE David Zhang. All rights reserved.
//

import SwiftUI

struct MetadataInputView: View {
    
    @Environment(\.dismiss) var dismissScreen
    
    struct Input: Identifiable {
        let id: UUID = UUID()
        var key: String = ""
        var value: String = ""
    }
    
    @State private var allInputs: [Input] = []
    var buttonAction: (([(key: String, value: String)]) -> Void)?
    
    var body: some View {
        List {
            ForEach($allInputs) { item in
                HStack {
                    TextField("Key", text: item.key)
                    TextField("Value", text: item.value)
                }
            }
            .onDelete(perform: { indexSet in
                delete(at: indexSet)
            })
            
            Button(action: {
                let allMetadata: [(String, String)] = allInputs.compactMap {
                    let sanitizedKey = $0.key.trimmingCharacters(in: .whitespacesAndNewlines)
                    let sanitizedValue = $0.value.trimmingCharacters(in: .whitespacesAndNewlines)
                    
                    if sanitizedKey.isEmpty {
                        return nil
                    }
                    
                    return (sanitizedKey, sanitizedValue)
                }
                
                buttonAction?(allMetadata)
                
                // Dismiss the screen
                dismissScreen()
            }, label: {
                HStack {
                    Spacer()
                    Text("Update")
                    Spacer()
                }
            })
            .disabled(allInputs.isEmpty)
        }
        .navigationTitle("Metadata")
        .navigationBarTitleDisplayMode(.inline)
        .toolbar(content: {
            Button(action: {
                allInputs.append(Input(key: "", value: ""))
            }, label: {
                Image(systemName: "plus")
            })
        })
    }
    
    func delete(at offsets: IndexSet) {
        allInputs.remove(atOffsets: offsets)
    }
}

#Preview {
    NavigationView {
        MetadataInputView()
    }
}
